@@ -5,15 +5,17 @@ import pywinauto.clipboard,pywinauto
 import win32gui,win32api,win32con
 from io import StringIO
 import http.client
+import talib as ta
+import talib.stream
 
 global app,hwnd,main_window,left_window,button_window_list,edit_windows_list,cang_df
 class Hx():
     #初始化
     def __init__(self):
-        global app,hwnd,main_window,left_window,button_window_list,edit_windows_list,cang_df
+        global app,hwnd,main_window,left_window,button_window_list,edit_windows_list,cang_df,right_window
     #叛逆账号
     def connect(self):
-        global app,hwnd,main_window,left_window,button_window_list,edit_windows_list,cang_df
+        global app,hwnd,main_window,left_window,button_window_list,edit_windows_list,cang_df,right_window
         button_window_list=[];edit_windows_list=[]
         app = pywinauto.application.Application()
         app.connect(title='网上股票交易系统5.0')
@@ -21,17 +23,23 @@ class Hx():
         main_window = app.window(handle=hwnd)
         lefthwnd = pywinauto.findwindows.find_windows(top_level_only=False, class_name='SysTreeView32', parent=hwnd)[0] 
         left_window = pywinauto.controls.common_controls.TreeViewWrapper(lefthwnd)
-        left_window.get_item([4]).click()
-        main_window.type_keys('{F6}')
+        righthwnd = pywinauto.findwindows.find_windows(top_level_only=False, class_name='#32770', parent=hwnd)[0] 
+        right_window = pywinauto.controls.common_controls.TreeViewWrapper(righthwnd)
+        #left_window.get_item([4]).click()
+        left_window.select('\\双向委托')
+        time.sleep(1)
+        right_window.type_keys('{F8}')
         edit_hwnd = pywinauto.findwindows.find_windows(top_level_only=False, class_name='Edit', parent=hwnd)#[459868, 594614, 528692]  右侧整个窗口
         button_hwnd = pywinauto.findwindows.find_windows(top_level_only=False, class_name='Button', parent=hwnd)
-        for i in [0,1,5]:
+        for i in [0,1,6]:
             button_window_list.append(pywinauto.controls.win32_controls.ButtonWrapper(button_hwnd[i]))
         for i in range(0,6):
             edit_windows_list.append(pywinauto.controls.win32_controls.EditWrapper(edit_hwnd[i]))
     #获取持仓
     def get_chicang(self):
-        global hwnd
+        global hwnd,right_window
+        right_window.type_keys('{F6}')
+        time.sleep(1)
         button_hwnd = pywinauto.findwindows.find_windows(top_level_only=False, class_name='Button', parent=hwnd)
         suanxin_window = pywinauto.controls.common_controls.TreeViewWrapper(button_hwnd[4])
         suanxin_window.click();time.sleep(1)
@@ -44,6 +52,8 @@ class Hx():
         cang_df = pd.read_csv(StringIO(s),dtype={'证券代码': object,'可用余额':int},usecols=[0,1,2,3,4,5,6,7,8,9,10])
         cang_df.drop(cang_df[cang_df['可用余额'] == 0].index, inplace=True)
         cang_df=cang_df.round(2)
+        right_window.type_keys('{F8}')
+        time.sleep(1)
         return cang_df
     #用最新价格更新持仓
     def updata_cang(self,cang_df):
@@ -70,7 +80,7 @@ class Hx():
         s=pywinauto.clipboard.GetData().replace('\t',',').split(',')
         d['资金余额']=float(s[8]);d['可用余额']=float(s[9]);d['总市值']=float(s[10]);d['总资产']=float(s[11])
         left_window.select('\\双向委托')
-        main_window.type_keys('{F6}')
+        main_window.type_keys('{F8}')
         return d
     #获取资金
     def get_kymoney(self):
@@ -142,18 +152,18 @@ class Hx():
                 self.sell(code,price,num)
                 time.sleep(0.3)
     #梭哈
-    def soha(self,n=20):
-        money = float(self.get_kymoney())/n
-        data = self.get_kzz_list()
-        zz_list = list(data['转债代码'].values[:n])
-        print(zz_list)
+    def soha(self,zz_list):
+        money = float(self.get_kymoney())/len(zz_list)
+        #data = self.get_kzz_list()
+        #zz_list = list(data['转债代码'].values[:n])
+        #print(zz_list)
         for code in zz_list:
             self.close_pop()
             price=self.get_real_data(code)['price']
             code=code[2:]
             price = round(price*1.01,2)
             num=int(money//price)//10*10
-            print(code,price,num)
+            #print(code,price,num)
             if num > 0:
                 self.buy(code,price,num)
         time.sleep(0.3)
@@ -204,7 +214,7 @@ class Hx():
         data=data[~data['强赎'].str.contains('最后交易日',na=False)]#.contains('最后交易日')]
         data.drop('强赎',axis=1,inplace=True)
         data = data.sort_values(by="涨跌幅",ascending=False)
-        data = data[(data['现价']>100) & (data['现价']<400)]
+        data = data[(data['现价']>105) & (data['现价']<400)]
         data = data[data['涨跌幅']<8]
         data = data.reset_index(drop=True)
         return data
@@ -228,5 +238,59 @@ class Hx():
         d['s_1'] = float(html[19]);d['vs_1'] = int(html[20])     #20是卖一的量
         d['vb_1'] = int(html[10]);d['dt_price'] = float(html[48])  #跌停价  
         d['zt_price'] = float(html[47]);d['liangbi'] = float(html[49]) #量比
-        d['dt']=html[30]
+        d['dt']=html[30];d['vol']=html[36]
         return d
+    #从新浪获取分时数据
+    def get_kzz_fenshi(self,code,scale=240,len=300):
+        url = 'https://quotes.sina.cn/cn/api/json_v2.php/CN_MarketDataService.getKLineData?symbol='+code+'&scale='+str(scale)+'&ma=no&datalen='+str(len)
+        headers={"User-Agent":"Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/65.0.3325.146 Safari/537.36"}
+        response = requests.get(url,headers=headers)
+        res_dict = json.loads(response.text)
+        a_list=[];b_list=[];c_list=[];d_list=[];e_list=[];f_list=[]
+        stock_list={'day' : a_list,'open' : b_list,'high' : c_list,'low' : d_list,'close' : e_list,'volume' : f_list}
+        for item in res_dict:
+            a_list.append(item['day']);b_list.append(item['open']);c_list.append(item['high'])
+            d_list.append(item['low']);e_list.append(item['close']);f_list.append(item['volume']) 
+        data=pd.DataFrame(stock_list)
+        if scale==240:
+            df = self.get_real_data(code)
+            temp_d ={}
+            temp_d['day']=df['dt'][:4]+'-'+df['dt'][4:6]+'-'+df['dt'][6:8]
+            temp_d['open']=df['open'];temp_d['high']=df['high'];temp_d['low']=df['low']
+            temp_d['close']=df['price'];temp_d['volume']=df['vol']
+            data = data.append(temp_d, ignore_index=True)
+        macd, macdsignal, macdhist = ta.MACD(data['close'], fastperiod=12, slowperiod=26, signalperiod=9)
+        data['dif']=macd;data['dea']=macdsignal;data['macd']=macdhist*2
+        data.dropna(axis = 0,inplace=True)
+        data = data.reset_index(drop=True)
+        return data
+    #用MACD判断买点
+    def is_macd(self,code,scale=240):
+        #df = ts.get_k_data(code,autype='qfq')
+        df = self.get_kzz_fenshi(code,scale)
+        macd, macdsignal, macdhist = ta.MACD(df['close'], fastperiod=12, slowperiod=26, signalperiod=9)
+        df['DIF']=macd;df['DEA']=macdsignal;df['MACD']=macdhist
+        tiao1 = (df['MACD']>df['MACD'].shift()) & (df['MACD'].shift()<df['MACD'].shift(2))
+        tiao2 = df['MACD'].shift(8).rolling(6).min() > 0
+        tiao3 = df['MACD'] < 0
+        tiao4 = df['MACD'].shift().rolling(4).max() < 0
+        tiao = tiao1 & tiao2 & tiao3 &tiao4
+        df.loc[df[tiao == True].index, 'buy'] = 'y'
+        if df.iloc[-1]['buy'] == 'y':
+            return True
+        else:
+            return False
+    #股票交易是否可交易
+    def is_jiaoyi(self):
+        jjr_list=['2021-01-01','2021-02-11','2021-02-12','2021-02-13','2021-02-14','2021-02-15','2021-02-16','2021-02-17',
+                    '2021-04-05','2021-05-01','2021-05-02','2021-05-03','2021-05-04','2021-05-05','2021-06-14','2021-09-20',
+                    '2021-09-21','2021-10-01','2021-10-02','2021-10-03','2021-10-04','2021-10-05','2021-10-06','2021-10-07']
+        week = [0,1,2,3,4]
+        now = str(datetime.datetime.now())#[:10]
+        kd_day = now[:10];kd_shi = int(now.replace(':','')[11:17])
+        shi_bool = (kd_shi >93000 and kd_shi <113000) or (kd_shi >130000 and kd_shi <150000)
+        week_bool = datetime.date.today().weekday() in week
+        if (kd_day not in jjr_list) and shi_bool and week_bool:
+            return True
+        else:
+            return False
\ No newline at end of file
